@@ -233,8 +233,12 @@ class HTTPPasswordHandler(object):
             local_passwordmgr = passwordmgr(local_ui)
             auth_token = local_passwordmgr.readauthtoken(base_url)
         except AttributeError:
-            # hg 1.8
-            from mercurial.url import readauthforuri
+            try:
+                # hg 1.8
+                from mercurial.url import readauthforuri
+            except ImportError:
+                # hg 1.9
+                from mercurial.httpconnection import readauthforuri
             res = readauthforuri(local_ui, base_url)
             if res:
                 group, auth_token = res
